@@ -422,8 +422,6 @@ def process_session(
                 i = 0
 
                 for ensemble in collected_ensembles:
-                    if not all(c.strength >= 5 for c in ensemble.clusters):
-                        continue
                     klass = ensemble.klass
                     if klass:
                         i += 1
